.. textory documentation master file, created by
   sphinx-quickstart on Thu Aug 29 11:06:58 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

===================================
Textory's documentation
===================================

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.3653939.svg
   :target: https://doi.org/10.5281/zenodo.3653939

Textory is a python library for the calculation of windowed statistics of arrays.
It can calculate windowed variograms, pseudo-cross variograms and standard statistics
like mean, std, min, max, etc. for rectangular and round windows.
It can also be used conveniently with xarrays and Satpy scenes.

.. _project: http://github.com/benr0/textory

.. toctree::
   :maxdepth: 2

   install
   overview
   usage
   satpy_usage

.. toctree::
   :maxdepth: 1

    Textory API <api/textory>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
